==> moodle_1.3.1.orig.tar.gz: moodle/lang/pt/countries.php <==
<?PHP // $Id: countries.php,v 1.2 2004/03/10 11:57:55 villate Exp $ 
      // countries.php - created with Moodle 1.2 Beta (2004022400)


$string['AD'] = 'Andorra';
$string['AE'] = 'Emiratos rabes Unidos';
$string['AF'] = 'Afeganisto';
$string['AG'] = 'Antgua e Barbuda';
$string['AI'] = 'Anguila';
$string['AL'] = 'Albnia';
$string['AM'] = 'Armenia';
$string['AN'] = 'Antilhas Holandesas';
$string['AO'] = 'Angola';
$string['AQ'] = 'Antrctida';
$string['AR'] = 'Argentina';
$string['AS'] = 'Samoa Americana';
$string['AT'] = 'ustria';
$string['AU'] = 'Austrlia';
$string['AW'] = 'Aruba';
$string['AZ'] = 'Azerbaijo ';
$string['BA'] = 'Bsnia-Herzegovina';
$string['BB'] = 'Barbados';
$string['BD'] = 'Bangladeche';
$string['BE'] = 'Blgica';
$string['BF'] = 'Burkina Faso';
$string['BG'] = 'Bulgria';
$string['BH'] = 'Barm';
$string['BI'] = 'Burundi';
$string['BJ'] = 'Benim';
$string['BM'] = 'Bermudas';
$string['BN'] = 'Brunei';
$string['BO'] = 'Bolvia';
$string['BR'] = 'Brasil';
$string['BS'] = 'Baamas';
$string['BT'] = 'Buto';
$string['BV'] = 'Ilha Bouvet';
$string['BW'] = 'Botsuana';
$string['BY'] = 'Belorrssia';
$string['BZ'] = 'Belize';
$string['CA'] = 'Canada';
$string['CC'] = 'Ilhas Cocos';
$string['CF'] = 'Repblica Centro-Africana';
$string['CG'] = 'Congo';
$string['CH'] = 'Sua';
$string['CI'] = 'Ilha do Marfim';
$string['CK'] = 'Ilhas Cook';
$string['CL'] = 'Chile';
$string['CM'] = 'Camares';
$string['CN'] = 'China';
$string['CO'] = 'Colmbia';
$string['CR'] = 'Costa Rica';
$string['CS'] = 'Srbia e Montenegro';
$string['CU'] = 'Cuba';
$string['CV'] = 'Cabo Verde';
$string['CX'] = 'Ilhas Christmas';
$string['CY'] = 'Chipre';
$string['CZ'] = 'Repblica Checa';
$string['DE'] = 'Alemanha';
$string['DJ'] = 'Jibuti';
$string['DK'] = 'Dinamarca';
$string['DM'] = 'Domnica';
$string['DO'] = 'Repblica Dominicana';
$string['DZ'] = 'Arglia';
$string['EC'] = 'Equador';
$string['EE'] = 'Estnia';
$string['EG'] = 'Egipto';
$string['EH'] = 'Sahara Occidental';
$string['ER'] = 'Eritreia';
$string['ES'] = 'Espanha';
$string['ET'] = 'Etipia';
$string['FI'] = 'Finlndia';
$string['FJ'] = 'Fiji';
$string['FK'] = 'Ilhas Falkland';
$string['FM'] = 'Micronsia';
$string['FO'] = 'Faro';
$string['FR'] = 'Frana';
$string['FX'] = 'Frana; Metropolitana';
$string['GA'] = 'Gabo';
$string['GB'] = 'Reino Unido';
$string['GD'] = 'Granada';
$string['GE'] = 'Gergia';
$string['GF'] = 'Guiana Francesa';
$string['GH'] = 'Gana';
$string['GI'] = 'Gibraltar';
$string['GL'] = 'Gronelndia';
$string['GM'] = 'Gmbia';
$string['GN'] = 'Guin';
$string['GP'] = 'Guadalupe';
$string['GQ'] = 'Guin Equatorial';
$string['GR'] = 'Grcia';
$string['GT'] = 'Guatemala';
$string['GU'] = 'Guam';
$string['GW'] = 'Guin-Bissau';
$string['GY'] = 'Guiana';
$string['HK'] = 'Hong Kong';
$string['HM'] = 'Ilhas Heard e McDonald';
$string['HN'] = 'Honduras';
$string['HR'] = 'Crocia';
$string['HT'] = 'Haiti';
$string['HU'] = 'Hungria';
$string['ID'] = 'Indonsia';
$string['IE'] = 'Irlanda';
$string['IL'] = 'Israel';
$string['IN'] = 'ndia';
$string['IO'] = 'Territrio Britnico no Oceano ndico';
$string['IQ'] = 'Iraque';
$string['IR'] = 'Iro';
$string['IS'] = 'Islndia';
$string['IT'] = 'Itlia';
$string['JM'] = 'Jamaica';
$string['JO'] = 'Jordo';
$string['JP'] = 'Japo';
$string['KE'] = 'Qunia';
$string['KG'] = 'Quirguizisto';
$string['KH'] = 'Camboja';
$string['KI'] = 'Quiribati';
$string['KM'] = 'Comores';
$string['KN'] = 'So Cristvo e Neves';
$string['KO'] = 'Kosovo';
$string['KP'] = 'Coreia do Norte';
$string['KR'] = 'Coreia do Sul';
$string['KW'] = 'Kuwait';
$string['KY'] = 'Ilhas Caimo';
$string['KZ'] = 'Cazaquisto';
$string['LA'] = 'Laos';
$string['LB'] = 'Lbano';
$string['LC'] = 'Santa Lcia';
$string['LI'] = 'Listestaine';
$string['LK'] = 'Sri Lanca';
$string['LR'] = 'Libria';
$string['LS'] = 'Lesoto';
$string['LT'] = 'Litunia';
$string['LU'] = 'Luxemburgo';
$string['LV'] = 'Letnia';
$string['LY'] = 'Lbia';
$string['MA'] = 'Marrocos';
$string['MC'] = 'Mnaco';
$string['MD'] = 'Moldvia';
$string['MG'] = 'Madagscar';
$string['MH'] = 'Ilhas Marshal';
$string['MK'] = 'Macednia';
$string['ML'] = 'Mali';
$string['MM'] = 'Birmnia';
$string['MN'] = 'Monglia';
$string['MO'] = 'Macau';
$string['MP'] = 'Marianas do Norte';
$string['MQ'] = 'Martinica';
$string['MR'] = 'Mauritnia';
$string['MS'] = 'Monserrate';
$string['MT'] = 'Malta';
$string['MU'] = 'Maurcia';
$string['MV'] = 'Maldivas';
$string['MW'] = 'Malavi';
$string['MX'] = 'Mxico';
$string['MY'] = 'Malsia';
$string['MZ'] = 'Moambique';
$string['NA'] = 'Nambia';
$string['NC'] = 'Nova Calednia';
$string['NE'] = 'Nger';
$string['NF'] = 'Ilha Norfolk';
$string['NG'] = 'Nigria';
$string['NI'] = 'Nicargua';
$string['NL'] = 'Pases Baixos';
$string['NO'] = 'Noruega';
$string['NP'] = 'Nepal';
$string['NR'] = 'Nauru';
$string['NU'] = 'Niue';
$string['NZ'] = 'Nova Zelndia';
$string['OM'] = 'Om';
$string['PA'] = 'Panam';
$string['PE'] = 'Peru';
$string['PF'] = 'Polinsia Francesa';
$string['PG'] = 'Papua - Nova Guin';
$string['PH'] = 'Filipinas';
$string['PK'] = 'Paquisto';
$string['PL'] = 'Polnia';
$string['PM'] = 'So Pedro e Miquelon';
$string['PN'] = 'Pitcairn';
$string['PR'] = 'Porto Rico';
$string['PT'] = 'Portugal';
$string['PW'] = 'Palau';
$string['PY'] = 'Paraguai';
$string['QA'] = 'Catar';
$string['RE'] = 'Reunio';
$string['RO'] = 'Romnia';
$string['RU'] = 'Rssia';
$string['RW'] = 'Ruanda';
$string['SA'] = 'Arabia Saudita';
$string['SB'] = 'Ilhas Salomo';
$string['SC'] = 'Seicheles';
$string['SD'] = 'Sudo';
$string['SE'] = 'Sucia';
$string['SG'] = 'Singapura';
$string['SH'] = 'Santa Helena';
$string['SI'] = 'Eslovnia';
$string['SJ'] = 'Svaldar e Jan Mayen';
$string['SK'] = 'Eslovquia';
$string['SL'] = 'Sierra Leoa';
$string['SM'] = 'So Marinho';
$string['SN'] = 'Senegal';
$string['SO'] = 'Somlia';
$string['SR'] = 'Suriname';
$string['ST'] = 'So Tom e Prncipe';
$string['SV'] = 'Salvador';
$string['SY'] = 'Sria';
$string['SZ'] = 'Suazilndia';
$string['TC'] = 'Ilhas Turcas e Caicos';
$string['TD'] = 'Chade';
$string['TF'] = 'Territrios Franceses do Sul';
$string['TG'] = 'Togo';
$string['TH'] = 'Tailndia';
$string['TJ'] = 'Tajiquisto';
$string['TK'] = 'Tokelau';
$string['TM'] = 'Turmenequisto';
$string['TN'] = 'Tunsia';
$string['TO'] = 'Tonga';
$string['TP'] = 'Tinor Leste';
$string['TR'] = 'Turquia';
$string['TT'] = 'Trinidad e Tobago';
$string['TV'] = 'Tuvalu';
$string['TW'] = 'Taiwan';
$string['TZ'] = 'Tanznia';
$string['UA'] = 'Ucrnia';
$string['UG'] = 'Uganda';
$string['US'] = 'Estados Unidos da Amrica';
$string['UY'] = 'Uruguai';
$string['UZ'] = 'Usbequisto';
$string['VA'] = 'Vaticano';
$string['VC'] = 'So Vicente e Granadinas';
$string['VE'] = 'Venezuela';
$string['VG'] = 'Ilhas Virgens (Britnicas)';
$string['VI'] = 'Ilhas Virgens (Americanas)';
$string['VN'] = 'Vietname';
$string['VU'] = 'Vanuatu';
$string['WA'] = 'Gales';
$string['WF'] = 'Wallis e Futuna';
$string['WS'] = 'Samoa';
$string['YE'] = 'Imen';
$string['YT'] = 'Mayotte';
$string['ZA'] = 'frica do Sul';
$string['ZM'] = 'Zambia';
$string['ZR'] = 'Zaire';
$string['ZW'] = 'Zimbabu';

?>

==> moodle_1.4.4.dfsg.1.orig.tar.gz: moodle/lang/pt/countries.php <==
<?PHP // $Id$ 
      // countries.php - created with Moodle 1.5 unstable development (2004083000)


$string['AD'] = 'Andorra';
$string['AE'] = 'Emiratos rabes Unidos';
$string['AF'] = 'Afeganisto';
$string['AG'] = 'Antgua e Barbuda';
$string['AI'] = 'Anguila';
$string['AL'] = 'Albnia';
$string['AM'] = 'Armenia';
$string['AN'] = 'Antilhas Holandesas';
$string['AO'] = 'Angola';
$string['AQ'] = 'Antrctida';
$string['AR'] = 'Argentina';
$string['AS'] = 'Samoa Americana';
$string['AT'] = 'ustria';
$string['AU'] = 'Austrlia';
$string['AW'] = 'Aruba';
$string['AZ'] = 'Azerbaijo ';
$string['BA'] = 'Bsnia-Herzegovina';
$string['BB'] = 'Barbados';
$string['BD'] = 'Bangladeche';
$string['BE'] = 'Blgica';
$string['BF'] = 'Burkina Faso';
$string['BG'] = 'Bulgria';
$string['BH'] = 'Barm';
$string['BI'] = 'Burundi';
$string['BJ'] = 'Benim';
$string['BM'] = 'Bermudas';
$string['BN'] = 'Brunei';
$string['BO'] = 'Bolvia';
$string['BR'] = 'Brasil';
$string['BS'] = 'Baamas';
$string['BT'] = 'Buto';
$string['BV'] = 'Ilha Bouvet';
$string['BW'] = 'Botsuana';
$string['BY'] = 'Belorrssia';
$string['BZ'] = 'Belize';
$string['CA'] = 'Canada';
$string['CC'] = 'Ilhas Cocos';
$string['CF'] = 'Repblica Centro-Africana';
$string['CG'] = 'Congo';
$string['CH'] = 'Sua';
$string['CI'] = 'Ilha do Marfim';
$string['CK'] = 'Ilhas Cook';
$string['CL'] = 'Chile';
$string['CM'] = 'Camares';
$string['CN'] = 'China';
$string['CO'] = 'Colmbia';
$string['CR'] = 'Costa Rica';
$string['CS'] = 'Srbia e Montenegro';
$string['CU'] = 'Cuba';
$string['CV'] = 'Cabo Verde';
$string['CX'] = 'Ilhas Christmas';
$string['CY'] = 'Chipre';
$string['CZ'] = 'Repblica Checa';
$string['DE'] = 'Alemanha';
$string['DJ'] = 'Jibuti';
$string['DK'] = 'Dinamarca';
$string['DM'] = 'Domnica';
$string['DO'] = 'Repblica Dominicana';
$string['DZ'] = 'Arglia';
$string['EC'] = 'Equador';
$string['EE'] = 'Estnia';
$string['EG'] = 'Egipto';
$string['EH'] = 'Sahara Occidental';
$string['ER'] = 'Eritreia';
$string['ES'] = 'Espanha';
$string['ET'] = 'Etipia';
$string['FI'] = 'Finlndia';
$string['FJ'] = 'Fiji';
$string['FK'] = 'Ilhas Falkland';
$string['FM'] = 'Micronsia';
$string['FO'] = 'Faro';
$string['FR'] = 'Frana';
$string['FX'] = 'Frana; Metropolitana';
$string['GA'] = 'Gabo';
$string['GB'] = 'Reino Unido';
$string['GD'] = 'Granada';
$string['GE'] = 'Gergia';
$string['GF'] = 'Guiana Francesa';
$string['GH'] = 'Gana';
$string['GI'] = 'Gibraltar';
$string['GL'] = 'Gronelndia';
$string['GM'] = 'Gmbia';
$string['GN'] = 'Guin';
$string['GP'] = 'Guadalupe';
$string['GQ'] = 'Guin Equatorial';
$string['GR'] = 'Grcia';
$string['GT'] = 'Guatemala';
$string['GU'] = 'Guam';
$string['GW'] = 'Guin-Bissau';
$string['GY'] = 'Guiana';
$string['HK'] = 'Hong Kong';
$string['HM'] = 'Ilhas Heard e McDonald';
$string['HN'] = 'Honduras';
$string['HR'] = 'Crocia';
$string['HT'] = 'Haiti';
$string['HU'] = 'Hungria';
$string['ID'] = 'Indonsia';
$string['IE'] = 'Irlanda';
$string['IL'] = 'Israel';
$string['IN'] = 'ndia';
$string['IO'] = 'Territrio Britnico no Oceano ndico';
$string['IQ'] = 'Iraque';
$string['IR'] = 'Iro';
$string['IS'] = 'Islndia';
$string['IT'] = 'Itlia';
$string['JM'] = 'Jamaica';
$string['JO'] = 'Jordo';
$string['JP'] = 'Japo';
$string['KE'] = 'Qunia';
$string['KG'] = 'Quirguizisto';
$string['KH'] = 'Camboja';
$string['KI'] = 'Quiribati';
$string['KM'] = 'Comores';
$string['KN'] = 'So Cristvo e Neves';
$string['KO'] = 'Kosovo';
$string['KP'] = 'Coreia do Norte';
$string['KR'] = 'Coreia do Sul';
$string['KW'] = 'Kuwait';
$string['KY'] = 'Ilhas Caimo';
$string['KZ'] = 'Cazaquisto';
$string['LA'] = 'Laos';
$string['LB'] = 'Lbano';
$string['LC'] = 'Santa Lcia';
$string['LI'] = 'Listestaine';
$string['LK'] = 'Sri Lanca';
$string['LR'] = 'Libria';
$string['LS'] = 'Lesoto';
$string['LT'] = 'Litunia';
$string['LU'] = 'Luxemburgo';
$string['LV'] = 'Letnia';
$string['LY'] = 'Lbia';
$string['MA'] = 'Marrocos';
$string['MC'] = 'Mnaco';
$string['MD'] = 'Moldvia';
$string['MG'] = 'Madagscar';
$string['MH'] = 'Ilhas Marshal';
$string['MK'] = 'Macednia';
$string['ML'] = 'Mali';
$string['MM'] = 'Birmnia';
$string['MN'] = 'Monglia';
$string['MO'] = 'Macau';
$string['MP'] = 'Marianas do Norte';
$string['MQ'] = 'Martinica';
$string['MR'] = 'Mauritnia';
$string['MS'] = 'Monserrate';
$string['MT'] = 'Malta';
$string['MU'] = 'Maurcia';
$string['MV'] = 'Maldivas';
$string['MW'] = 'Malavi';
$string['MX'] = 'Mxico';
$string['MY'] = 'Malsia';
$string['MZ'] = 'Moambique';
$string['NA'] = 'Nambia';
$string['NC'] = 'Nova Calednia';
$string['NE'] = 'Nger';
$string['NF'] = 'Ilha Norfolk';
$string['NG'] = 'Nigria';
$string['NI'] = 'Nicargua';
$string['NL'] = 'Pases Baixos';
$string['NO'] = 'Noruega';
$string['NP'] = 'Nepal';
$string['NR'] = 'Nauru';
$string['NU'] = 'Niue';
$string['NZ'] = 'Nova Zelndia';
$string['OM'] = 'Om';
$string['PA'] = 'Panam';
$string['PE'] = 'Peru';
$string['PF'] = 'Polinsia Francesa';
$string['PG'] = 'Papua - Nova Guin';
$string['PH'] = 'Filipinas';
$string['PK'] = 'Paquisto';
$string['PL'] = 'Polnia';
$string['PM'] = 'So Pedro e Miquelon';
$string['PN'] = 'Pitcairn';
$string['PR'] = 'Porto Rico';
$string['PS'] = 'Palestina';
$string['PT'] = 'Portugal';
$string['PW'] = 'Palau';
$string['PY'] = 'Paraguai';
$string['QA'] = 'Catar';
$string['RE'] = 'Reunio';
$string['RO'] = 'Romnia';
$string['RU'] = 'Rssia';
$string['RW'] = 'Ruanda';
$string['SA'] = 'Arabia Saudita';
$string['SB'] = 'Ilhas Salomo';
$string['SC'] = 'Seicheles';
$string['SD'] = 'Sudo';
$string['SE'] = 'Sucia';
$string['SG'] = 'Singapura';
$string['SH'] = 'Santa Helena';
$string['SI'] = 'Eslovnia';
$string['SJ'] = 'Svaldar e Jan Mayen';
$string['SK'] = 'Eslovquia';
$string['SL'] = 'Sierra Leoa';
$string['SM'] = 'So Marinho';
$string['SN'] = 'Senegal';
$string['SO'] = 'Somlia';
$string['SR'] = 'Suriname';
$string['ST'] = 'So Tom e Prncipe';
$string['SV'] = 'Salvador';
$string['SY'] = 'Sria';
$string['SZ'] = 'Suazilndia';
$string['TC'] = 'Ilhas Turcas e Caicos';
$string['TD'] = 'Chade';
$string['TF'] = 'Territrios Franceses do Sul';
$string['TG'] = 'Togo';
$string['TH'] = 'Tailndia';
$string['TJ'] = 'Tajiquisto';
$string['TK'] = 'Tokelau';
$string['TM'] = 'Turmenequisto';
$string['TN'] = 'Tunsia';
$string['TO'] = 'Tonga';
$string['TP'] = 'Tinor Leste';
$string['TR'] = 'Turquia';
$string['TT'] = 'Trinidad e Tobago';
$string['TV'] = 'Tuvalu';
$string['TW'] = 'Taiwan';
$string['TZ'] = 'Tanznia';
$string['UA'] = 'Ucrnia';
$string['UG'] = 'Uganda';
$string['US'] = 'Estados Unidos da Amrica';
$string['UY'] = 'Uruguai';
$string['UZ'] = 'Usbequisto';
$string['VA'] = 'Vaticano';
$string['VC'] = 'So Vicente e Granadinas';
$string['VE'] = 'Venezuela';
$string['VG'] = 'Ilhas Virgens (Britnicas)';
$string['VI'] = 'Ilhas Virgens (Americanas)';
$string['VN'] = 'Vietname';
$string['VU'] = 'Vanuatu';
$string['WA'] = 'Gales';
$string['WF'] = 'Wallis e Futuna';
$string['WS'] = 'Samoa';
$string['YE'] = 'Imen';
$string['YT'] = 'Mayotte';
$string['ZA'] = 'frica do Sul';
$string['ZM'] = 'Zambia';
$string['ZR'] = 'Zaire';
$string['ZW'] = 'Zimbabu';

?>
